@@ -34,6 +34,13 @@ class FacileToolkit2:
     ROBOT_LIBRARY_SCOPE = "GLOBAL"
     ROBOT_LIBRARY_DOC_FORMAT = "ROBOT"
 
+    def __init__(self):
+        self.ajax_activation = "800ms"
+
+    @keyword
+    def set_ajax_activation(self, timeout):
+        self.ajax_activation = timeout
+
     @keyword
     def wait(self, keyword, *keywordargs, retry="15x", retry_interval="1s"):
         """
@@ -200,8 +207,9 @@ class FacileToolkit2:
             self.sl.log_location()
             self.sl.wait_until_location_contains(url, timeout)
             self.dom_is_loaded(timeout=timeout)
-        finally:
+        except:
             self.sl.capture_page_screenshot(filename="EMBED")
+        finally:
             self.sl.log_location()
 
     @keyword
@@ -272,7 +280,7 @@ class FacileToolkit2:
         Selects the first autocomplete option for auto-complete fields.
         """
         self.set_selenium_library()
-        self.sl.wait_until_element_is_visible(locator_option)
+        self.sl.wait_until_element_is_visible(locator_option, timeout=timeout, error=error)
         self.click_js(locator_option)
 
     @keyword
@@ -346,14 +354,18 @@ class FacileToolkit2:
             raise Error(error_thrown)
 
     @keyword
-    def wait_ajax(self, timeout="60s", wait_active="400ms"):
+    def wait_ajax(self, timeout="60s", wait_active=None):
         self.set_selenium_library()
+        if is_noney(wait_active):
+            wait_active = self.ajax_activation
         BuiltIn().run_keyword_and_ignore_error("wait_ajax_activation", wait_active)
         self.sl.wait_for_condition('if(typeof(jQuery) == "function") {return jQuery.active == 0} return false', timeout)
 
     @keyword
-    def wait_ajax_activation(self, timeout="400ms"):
+    def wait_ajax_activation(self, timeout=None):
         self.set_selenium_library()
+        if is_noney(timeout):
+            timeout = self.ajax_activation
         self.sl.wait_for_condition('if(typeof(jQuery) == "function") {return jQuery.active == 1} return false', timeout)
 
     @keyword
@@ -674,7 +686,7 @@ class FacileToolkit2:
             except ElementNotFound as err:
                 not_found = str(err)
             except StaleElementReferenceException as err:
-                self.sl.info('Suppressing StaleElementReferenceException from Selenium.')
+                self.lc.info('Suppressing StaleElementReferenceException from Selenium.')
                 not_found = err
             else:
                 not_found = None
